var Channel, Client, Resource, User, clone, request, sys;
var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
  for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
  function ctor() { this.constructor = child; }
  ctor.prototype = parent.prototype;
  child.prototype = new ctor;
  child.__super__ = parent.prototype;
  return child;
};
request = require('request');
sys = require('sys');
clone = function(o) {
  var c, k, v;
  c = {};
  for (k in o) {
    v = o[k];
    c[k] = v;
  }
  return c;
};
Resource = (function() {
  function Resource(client, type, name) {
    this.client = client;
    this.name = name;
    this.url = this.client.url + '/' + type + 's/' + this.name;
  }
  Resource.prototype.send = function(message, callback) {
    return request({
      uri: this.url,
      method: 'POST',
      headers: this.client.headers,
      json: message
    }, function(err, response, body) {
      var numDelivered;
      numDelivered = void 0;
      if (!err && response.statusCode === 200) {
        numDelivered = JSON.parse(body).messages_sent;
      }
      return callback(err, numDelivered);
    });
  };
  return Resource;
})();
User = (function() {
  function User() {
    User.__super__.constructor.apply(this, arguments);
  }
  __extends(User, Resource);
  User.prototype.isConnected = function(callback) {
    return request({
      uri: this.url,
      headers: this.client.headers
    }, function(err, response, body) {
      var connected;
      connected = !err && response.statusCode === 200;
      return callback(err, connected);
    });
  };
  User.prototype.disconnect = function(callback) {
    var headers;
    headers = clone(this.headers);
    headers["Content-Length"] = '0';
    return request({
      uri: this.url,
      method: 'DELETE',
      headers: headers
    }, function(err, response, body) {
      if (!err && response.statusCode !== 204) {
        err = "Unexpected response code: " + response.statusCode;
      }
      return callback(err);
    });
  };
  return User;
})();
Channel = (function() {
  function Channel() {
    Channel.__super__.constructor.apply(this, arguments);
  }
  __extends(Channel, Resource);
  Channel.prototype.usersConnected = function(callback) {
    return request({
      uri: this.url,
      headers: this.headers
    }, function(err, response, body) {
      var users;
      users = void 0;
      if (!err && response.statusCode === 200) {
        users = JSON.parse(body).users;
      } else {
        err = "Unexpected response code: " + response.statusCode;
      }
      return callback(err, users);
    });
  };
  return Channel;
})();
Client = (function() {
  Client.prototype.version = '1';
  function Client(apiKey, secretKey, options) {
    this.apiKey = apiKey;
    this.secretKey = secretKey;
    this.headers = {
      'X-Beacon-Secret-Key': this.secretKey
    };
    this.url = 'http://api.beaconpush.com/1.0.0/' + this.apiKey;
  }
  Client.prototype.channel = function(name) {
    return new Channel(this, 'channel', name);
  };
  Client.prototype.user = function(name) {
    return new User(this, 'user', name);
  };
  Client.prototype.usersConnected = function(callback) {
    return request({
      uri: this.url + '/users',
      headers: this.headers
    }, function(err, response, body) {
      var numConnected;
      numConnected = void 0;
      if (!err && response.statusCode === 200) {
        numConnected = JSON.parse(body).online;
      }
      return callback(err, numConnected);
    });
  };
  return Client;
})();
module.exports = Client;